@@ -2,9 +2,10 @@ use fuel_core::service::{Config, FuelService};
 use fuel_gql_client::client::schema::coin::Coin;
 use fuel_gql_client::client::{FuelClient, PageDirection, PaginationRequest};
 use fuel_tx::Receipt;
-use fuel_tx::{Address, Color, Input, Output, Transaction};
+use fuel_tx::{Address, AssetId, Input, Output, Transaction};
 use fuel_vm::consts::REG_ONE;
 use std::io;
+use std::net::SocketAddr;
 
 use fuel_vm::prelude::Opcode;
 use fuels_core::errors::Error;
@@ -45,6 +46,11 @@ impl Provider {
         Ok(FuelClient::from(srv.bound_address))
     }
 
+    /// Connects to an existing node at the given address
+    pub async fn connect(socket: SocketAddr) -> Result<FuelClient, Error> {
+        Ok(FuelClient::from(socket))
+    }
+
     /// Shallow wrapper on client's coins API.
     pub async fn get_coins(&self, from: &Address) -> Result<Vec<Coin>, ProviderError> {
         let mut coins: Vec<Coin> = vec![];
@@ -78,14 +84,14 @@ impl Provider {
     pub async fn get_spendable_coins(
         &self,
         from: &Address,
-        color: Color,
+        asset_id: AssetId,
         amount: u64,
     ) -> io::Result<Vec<Coin>> {
         let res = self
             .client
             .coins_to_spend(
                 &from.to_string(),
-                vec![(format!("{:#x}", color).as_str(), amount)],
+                vec![(format!("{:#x}", asset_id).as_str(), amount)],
                 None,
             )
             .await?;
