@@ -2,10 +2,9 @@ use crate::provider::{Provider, ProviderError};
 use crate::signature::Signature;
 use crate::Signer;
 use async_trait::async_trait;
+use fuel_crypto::Hasher;
 use fuel_gql_client::client::schema::coin::Coin;
-use fuel_tx::crypto::Hasher;
-use fuel_tx::{Bytes64, Color, Input, Output, Receipt, Transaction, UtxoId, Witness};
-use fuel_types::Address;
+use fuel_tx::{Address, AssetId, Bytes64, Input, Output, Receipt, Transaction, UtxoId, Witness};
 use fuel_vm::crypto::secp256k1_sign_compact_recoverable;
 use secp256k1::{PublicKey, Secp256k1, SecretKey};
 use std::{fmt, io};
@@ -109,7 +108,7 @@ impl Wallet {
     }
 
     /// Transfer funds from this wallet to another `Address`.
-    /// Fails if amount for color is larger than address's spendable coins.
+    /// Fails if amount for asset ID is larger than address's spendable coins.
     ///
     /// # Examples
     /// ```
@@ -118,7 +117,7 @@ impl Wallet {
     /// use fuels_signers::util::test_helpers::{
     ///     setup_address_and_coins, setup_local_node, setup_test_provider,
     /// };
-    /// use fuel_tx::{Bytes32, Color, Input, Output, UtxoId};
+    /// use fuel_tx::{Bytes32, AssetId, Input, Output, UtxoId};
     /// use rand::{rngs::StdRng, RngCore, SeedableRng};
     /// use secp256k1::SecretKey;
     /// use std::str::FromStr;
@@ -153,16 +152,16 @@ impl Wallet {
         &self,
         to: &Address,
         amount: u64,
-        color: Color,
+        asset_id: AssetId,
     ) -> io::Result<Vec<Receipt>> {
-        let spendable = self.get_spendable_coins(&color, amount).await?;
+        let spendable = self.get_spendable_coins(&asset_id, amount).await?;
 
         let mut inputs: Vec<Input> = vec![];
         let outputs: Vec<Output> = vec![
-            Output::coin(*to, amount, color),
+            Output::coin(*to, amount, asset_id),
             // Note that the change will be computed by the node.
-            // Here we only have to tell the node who will own the change and its color.
-            Output::change(self.address(), 0, color),
+            // Here we only have to tell the node who will own the change and its asset ID.
+            Output::change(self.address(), 0, asset_id),
         ];
 
         for coin in spendable {
@@ -170,7 +169,7 @@ impl Wallet {
                 UtxoId::from(coin.utxo_id),
                 coin.owner.into(),
                 coin.amount.0,
-                color,
+                asset_id,
                 0,
                 0,
                 vec![],
@@ -198,10 +197,14 @@ impl Wallet {
     /// Gets spendable coins from this wallet.
     /// Note that this is a simple wrapper on provider's
     /// `get_spendable_coins`.
-    pub async fn get_spendable_coins(&self, color: &Color, amount: u64) -> io::Result<Vec<Coin>> {
+    pub async fn get_spendable_coins(
+        &self,
+        asset_id: &AssetId,
+        amount: u64,
+    ) -> io::Result<Vec<Coin>> {
         Ok(self
             .provider
-            .get_spendable_coins(&self.address(), *color, amount)
+            .get_spendable_coins(&self.address(), *asset_id, amount)
             .await?)
     }
 }
